@@ -47,6 +47,7 @@ sub _buildErrorCode {
     'Invalid input detected|Type help or ',
     'Line has invalid autocommand',
     'Invalid input detected|Incomplete command',
+    'Invalid |\%Error ',
   ];
   return $codes;
 }
@@ -59,8 +60,10 @@ sub _buildBufferCode {
   my %mapping = (
     more     => '--More--',
     interact => {
-      '\[startup-config\]\?'   => ' ',
-      'overwrite\?\s*\[Y\/N\]' => 'Y',
+      '\[startup-config\]\?'              => ' ',
+      'Address or name of remote host \[' => "\r",
+      'Destination filename \['           => "\r",
+      'overwrite\?\s*\[Y\/N\]'            => 'Y',
     }
   );
 
