@@ -18,7 +18,7 @@ with 'Net::Connector::Role';
 #------------------------------------------------------------------------------
 sub _buildPrompt {
   my $self   = shift;
-  my $prompt = '(\Q(active)\E|\Q(passive)\E)(\Q>\E|\Q#\E)';
+  my $prompt = '(active|\passive)\)[>#]';
   return $prompt;
 }
 
